@@ -5,6 +5,5 @@ from django.apps import AppConfig
 
 
 class CoreParserAppConfig(AppConfig):
-    name = 'core_parser_app'
+    name = "core_parser_app"
     verbose_name = "Core Parser App"
-
